==> ejc-trade-impl-3.0.0-20220627.094247-13-sources.jar: com/ejianc/business/trade/bean/CghtdjEntity.java <==
package com.ejianc.business.trade.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.trade.bean.CghtdjZiEntity;
/**
 * 采购合同登记主实体
 * 
 * @author generator
 * 
 */
 @TableName("t_trade_cghtdj")
public class CghtdjEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="ht_code")
    private String htCode; // 合同编号
    @TableField(value="ht_name")
    private String htName; // 合同名称
    @TableField(value="gf_name")
    private String gfName; // 供方名称
    @TableField(value="lxr")
    private String lxr; // 联系人
    @TableField(value="lxfs")
    private String lxfs; // 联系方式
    @TableField(value="cgpl_id")
    private Long cgplId; // 采购品类id
    @TableField(value="cgpl_name")
    private String cgplName; // 采购品类
    @TableField(value="glxsdd")
    private String glxsdd; // 关联销售订单
    @TableField(value="gf_id")
    private Long gfId; // 供方id
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="cghtdjZiService", pidName = "zhuId")
    private List<CghtdjZiEntity> cghtdjZiList = new ArrayList<>(); // 采购合同登记子实体




    public Long getGfId() {
        return gfId;
    }

    public void setGfId(Long gfId) {
        this.gfId = gfId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getHtCode() {
        return htCode;
    }

    public void setHtCode(String htCode) {
        this.htCode = htCode;
    }
    public String getHtName() {
        return htName;
    }

    public void setHtName(String htName) {
        this.htName = htName;
    }
    public String getGfName() {
        return gfName;
    }

    public void setGfName(String gfName) {
        this.gfName = gfName;
    }
    public String getLxr() {
        return lxr;
    }

    public void setLxr(String lxr) {
        this.lxr = lxr;
    }
    public String getLxfs() {
        return lxfs;
    }

    public void setLxfs(String lxfs) {
        this.lxfs = lxfs;
    }
    public Long getCgplId() {
        return cgplId;
    }

    public void setCgplId(Long cgplId) {
        this.cgplId = cgplId;
    }
    public String getCgplName() {
        return cgplName;
    }

    public void setCgplName(String cgplName) {
        this.cgplName = cgplName;
    }
    public String getGlxsdd() {
        return glxsdd;
    }

    public void setGlxsdd(String glxsdd) {
        this.glxsdd = glxsdd;
    }
    

    public List<CghtdjZiEntity> getCghtdjZiList() {
        return cghtdjZiList;
    }

    public void setCghtdjZiList(List<CghtdjZiEntity> cghtdjZiList) {
        this.cghtdjZiList = cghtdjZiList;
    }
}

==> ejc-trade-impl-3.0.0-20231113.081702-39-sources.jar: com/ejianc/business/trade/bean/CghtdjEntity.java <==
package com.ejianc.business.trade.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.trade.bean.CghtdjZiEntity;
/**
 * 采购合同登记主实体
 * 
 * @author generator
 * 
 */
 @TableName("t_trade_cghtdj")
public class CghtdjEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="ht_code")
    private String htCode; // 合同编号
    @TableField(value="ht_name")
    private String htName; // 合同名称
    @TableField(value="gf_name")
    private String gfName; // 供方名称
    @TableField(value="lxr")
    private String lxr; // 联系人
    @TableField(value="lxfs")
    private String lxfs; // 联系方式
    @TableField(value="cgpl_id")
    private Long cgplId; // 采购品类id
    @TableField(value="cgpl_name")
    private String cgplName; // 采购品类
    @TableField(value="glxsdd")
    private String glxsdd; // 关联销售订单
    @TableField(value="gf_id")
    private Long gfId; // 供方id
    @TableField(value="contract_value")
    private BigDecimal contractValue; // 合同总金额
    @TableField(value="contract_value_ch")
    private String contractValueCh; // 合同总金额(大写)
    @TableField(value="cj_name")
    private String cjName; // 厂家名称
    @TableField(value="cj_code")
    private String cjCode; // 账号
    @TableField(value="bank")
    private String bank; // 开户行
    @TableField(value="qd_date")
    private Date qdDate; // 签订日期
    @TableField(value="fk_date")
    private Date fkDate; // 付款日期


    public BigDecimal getContractValue() {
        return contractValue;
    }

    public void setContractValue(BigDecimal contractValue) {
        this.contractValue = contractValue;
    }

    public String getContractValueCh() {
        return contractValueCh;
    }

    public void setContractValueCh(String contractValueCh) {
        this.contractValueCh = contractValueCh;
    }

    public String getCjName() {
        return cjName;
    }

    public void setCjName(String cjName) {
        this.cjName = cjName;
    }

    public String getCjCode() {
        return cjCode;
    }

    public void setCjCode(String cjCode) {
        this.cjCode = cjCode;
    }

    public String getBank() {
        return bank;
    }

    public void setBank(String bank) {
        this.bank = bank;
    }

    public Date getQdDate() {
        return qdDate;
    }

    public void setQdDate(Date qdDate) {
        this.qdDate = qdDate;
    }

    public Date getFkDate() {
        return fkDate;
    }

    public void setFkDate(Date fkDate) {
        this.fkDate = fkDate;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="cghtdjZiService", pidName = "zhuId")
    private List<CghtdjZiEntity> cghtdjZiList = new ArrayList<>(); // 采购合同登记子实体




    public Long getGfId() {
        return gfId;
    }

    public void setGfId(Long gfId) {
        this.gfId = gfId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getHtCode() {
        return htCode;
    }

    public void setHtCode(String htCode) {
        this.htCode = htCode;
    }
    public String getHtName() {
        return htName;
    }

    public void setHtName(String htName) {
        this.htName = htName;
    }
    public String getGfName() {
        return gfName;
    }

    public void setGfName(String gfName) {
        this.gfName = gfName;
    }
    public String getLxr() {
        return lxr;
    }

    public void setLxr(String lxr) {
        this.lxr = lxr;
    }
    public String getLxfs() {
        return lxfs;
    }

    public void setLxfs(String lxfs) {
        this.lxfs = lxfs;
    }
    public Long getCgplId() {
        return cgplId;
    }

    public void setCgplId(Long cgplId) {
        this.cgplId = cgplId;
    }
    public String getCgplName() {
        return cgplName;
    }

    public void setCgplName(String cgplName) {
        this.cgplName = cgplName;
    }
    public String getGlxsdd() {
        return glxsdd;
    }

    public void setGlxsdd(String glxsdd) {
        this.glxsdd = glxsdd;
    }
    

    public List<CghtdjZiEntity> getCghtdjZiList() {
        return cghtdjZiList;
    }

    public void setCghtdjZiList(List<CghtdjZiEntity> cghtdjZiList) {
        this.cghtdjZiList = cghtdjZiList;
    }
}
